@@ -39,23 +39,23 @@ Base64-encoded response, from the SAMLResponse CGI parameter.
 =cut
 
 sub handle_response {
-        my ($self, $response) = @_;
+    my ($self, $response) = @_;
 
-        # unpack and check the signature
-        my $xml = decode_base64($response);
-        my $x = Net::SAML2::XML::Sig->new({ x509 => 1 });
-        my $ret = $x->verify($xml);
-        die "signature check failed" unless $ret;
+    # unpack and check the signature
+    my $xml = decode_base64($response);
+    my $x = Net::SAML2::XML::Sig->new({ x509 => 1 });
+    my $ret = $x->verify($xml);
+    die "signature check failed" unless $ret;
 
-        # verify the signing certificate
-        my $cert = $x->signer_cert;
-        my $ca = Crypt::OpenSSL::VerifyX509->new($self->cacert);
-        $ret = $ca->verify($cert);
+    # verify the signing certificate
+    my $cert = $x->signer_cert;
+    my $ca = Crypt::OpenSSL::VerifyX509->new($self->cacert);
+    $ret = $ca->verify($cert);
 
-        if ($ret) {
-                return sprintf("%s (verified)", $cert->subject);
-        }
-        return;
+    if ($ret) {
+        return sprintf("%s (verified)", $cert->subject);
+    }
+    return;
 }
-        
-1;
+
+__PACKAGE__->meta->make_immutable;
