@@ -69,28 +69,28 @@ authentication process with the IdP.
 =cut
 
 sub sign {
-        my ($self, $request, $relaystate) = @_;
+    my ($self, $request, $relaystate) = @_;
 
-        my $input = "$request";
-        my $output = '';
+    my $input = "$request";
+    my $output = '';
 
-        rawdeflate \$input => \$output;
-        my $req = encode_base64($output, '');
+    rawdeflate \$input => \$output;
+    my $req = encode_base64($output, '');
 
-        my $u = URI->new($self->url);
-        $u->query_param($self->param, $req);
-        $u->query_param('RelayState', $relaystate) if defined $relaystate;
-        $u->query_param('SigAlg', 'http://www.w3.org/2000/09/xmldsig#rsa-sha1');
+    my $u = URI->new($self->url);
+    $u->query_param($self->param, $req);
+    $u->query_param('RelayState', $relaystate) if defined $relaystate;
+    $u->query_param('SigAlg', 'http://www.w3.org/2000/09/xmldsig#rsa-sha1');
 
-        my $key_string = read_file($self->key);
-        my $rsa_priv = Crypt::OpenSSL::RSA->new_private_key($key_string);
+    my $key_string = read_file($self->key);
+    my $rsa_priv = Crypt::OpenSSL::RSA->new_private_key($key_string);
 
-        my $to_sign = $u->query;
-        my $sig = encode_base64($rsa_priv->sign($to_sign), '');
-        $u->query_param('Signature', $sig);
+    my $to_sign = $u->query;
+    my $sig = encode_base64($rsa_priv->sign($to_sign), '');
+    $u->query_param('Signature', $sig);
 
-        my $url = $u->as_string;
-        return $url;
+    my $url = $u->as_string;
+    return $url;
 }
 
 =head2 verify($url)
@@ -102,31 +102,30 @@ Verifies the signature on the response.
 =cut
 
 sub verify {
-        my ($self, $url) = @_;
-        my $u = URI->new($url);
+    my ($self, $url) = @_;
+    my $u = URI->new($url);
         
-        # verify the response
-        my $sigalg = $u->query_param('SigAlg');
-        die "can't verify '$sigalg' signatures"
-             unless $sigalg eq 'http://www.w3.org/2000/09/xmldsig#rsa-sha1';
+    # verify the response
+    my $sigalg = $u->query_param('SigAlg');
+    die "can't verify '$sigalg' signatures"
+         unless $sigalg eq 'http://www.w3.org/2000/09/xmldsig#rsa-sha1';
 
-        my $cert = Crypt::OpenSSL::X509->new_from_string($self->cert);
-        my $rsa_pub = Crypt::OpenSSL::RSA->new_public_key($cert->pubkey);
+    my $cert = Crypt::OpenSSL::X509->new_from_string($self->cert);
+    my $rsa_pub = Crypt::OpenSSL::RSA->new_public_key($cert->pubkey);
         
-        my $sig = decode_base64($u->query_param_delete('Signature'));
-        my $signed = $u->query;
-        die "bad sig" unless $rsa_pub->verify($signed, $sig);
+    my $sig = decode_base64($u->query_param_delete('Signature'));
+    my $signed = $u->query;
+    die "bad sig" unless $rsa_pub->verify($signed, $sig);
 
-        # unpack the SAML request
-        my $deflated = decode_base64($u->query_param($self->param));
-        my $request = '';
-        rawinflate \$deflated => \$request;
+    # unpack the SAML request
+    my $deflated = decode_base64($u->query_param($self->param));
+    my $request = '';
+    rawinflate \$deflated => \$request;
         
-        # unpack the relaystate
-        my $relaystate = $u->query_param('RelayState');
+    # unpack the relaystate
+    my $relaystate = $u->query_param('RelayState');
 
-        return ($request, $relaystate);
+    return ($request, $relaystate);
 }
 
-1;
-        
+__PACKAGE__->meta->make_immutable;
